import numpy as np
import matplotlib.pylab as plt
import matplotlib.animation as animation

def plot_circle(x, y, r):
    """
    Plot a circle with radius r at point (x, y) in current plot handle
    """
    theta = np.linspace(0, 2*np.pi, 100)
    X = x + r * np.sin(theta)
    Y = y + r * np.cos(theta)
    plt.plot(X, Y, color="steelblue")


def plot_plate(X, Y, R, a):
    plt.figure(figsize=(6,6))

    # plot plate boundaries
    plt.plot([0, 0, a, a, 0], [0, a, a, 0, 0], 'k-')

    # plot circles
    for i, (x, y, r) in enumerate(zip(X, Y, R)):
        plot_circle(x, y, r)
        plt.plot(x, y, color="steelblue", marker="x")
        txt = "$s_" + str(i+1) + "$"
        plt.text(x+0.2, y+0.2, txt)

    plt.grid(True)
    plt.xlabel('$x$')
    plt.ylabel("$y$")
    plt.axis("equal")
    # plt.show()


def animate_pendulum(Theta, dt=0.03):
    '''
    Create animation of a pendulum, where Theta contains the trajectory of its
    angle. dt defines the time gap (in seconds) between two succesive entries.
    '''
    fig = plt.figure()
    ax = fig.add_subplot(111, autoscale_on=False, xlim=(-1.2, 1.2), ylim=(-1.2, 1.2))
    ax.set_aspect('equal')
    ax.axis('off')

    # create empty plot
    line, = ax.plot([], [], 'o-', lw=2)

    def init():
        # placeholder for data
        line.set_data([], [])
        return line,

    def animate(i):
        # plot pendulum as defined by i-th entry of Theta
        thisx = [0, -np.sin(Theta[i])]
        thisy = [0, np.cos(Theta[i])]
        line.set_data(thisx, thisy)
        return line,

    ani = animation.FuncAnimation(fig, animate, Theta.size,
                                  interval=dt*1000, repeat_delay=500,
                                  blit=True, init_func=init)
    return ani